

use Test::More tests => 5;

use_ok( 'Games::Bingo' );
use_ok( 'Games::Bingo::Constants' );
use_ok( 'Games::Bingo::Column' );
use_ok( 'Games::Bingo::ColumnCollection' );
use_ok( 'Games::Bingo::Card' );
